# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.blacklist_management_api import BlacklistManagementApi  # noqa: E501
from allegro_api.rest import ApiException


class TestBlacklistManagementApi(unittest.TestCase):
    """BlacklistManagementApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.blacklist_management_api.BlacklistManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_do_add_to_black_list(self):
        """Test case for do_add_to_black_list

        Add a users to the blacklist  # noqa: E501
        """
        pass

    def test_do_get_black_list_users(self):
        """Test case for do_get_black_list_users

        Get list of blacklisted users  # noqa: E501
        """
        pass

    def test_do_remove_from_black_list(self):
        """Test case for do_remove_from_black_list

        Remove users from the blacklist  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.modification import Modification  # noqa: E501
from allegro_api.rest import ApiException

class TestModification(unittest.TestCase):
    """Modification unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Modification
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.modification.Modification()  # noqa: E501
        if include_optional :
            return Modification(
                additional_services_group = allegro_api.models.additional_services_group.AdditionalServicesGroup(
                    id = '0', ), 
                delivery = allegro_api.models.modification_delivery.ModificationDelivery(
                    shipping_rates = allegro_api.models.shipping_rates.ShippingRates(
                        id = '0', ), ), 
                payments = allegro_api.models.modification_payments.ModificationPayments(
                    invoice = 'VAT', ), 
                promotion = allegro_api.models.modification_promotion.ModificationPromotion(
                    bold = False, 
                    department_page = False, 
                    emphasized = False, 
                    emphasized_highlight_bold_package = False, 
                    highlight = False, ), 
                size_table = allegro_api.models.modification_size_table.ModificationSizeTable(
                    id = '0', ), 
                publication = allegro_api.models.modification_publication.ModificationPublication(
                    duration = 'PT72H', 
                    duration_unlimited = False, )
            )
        else :
            return Modification(
        )

    def testModification(self):
        """Test Modification"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CompatibilityListTextItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'text': 'str'
    }

    attribute_map = {
        'type': 'type',
        'text': 'text'
    }

    def __init__(self, type='TEXT', text=None, local_vars_configuration=None):  # noqa: E501
        """CompatibilityListTextItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._text = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.text = text

    @property
    def type(self):
        """Gets the type of this CompatibilityListTextItem.  # noqa: E501


        :return: The type of this CompatibilityListTextItem.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CompatibilityListTextItem.


        :param type: The type of this CompatibilityListTextItem.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def text(self):
        """Gets the text of this CompatibilityListTextItem.  # noqa: E501

        Text description of the compatible item. Maximum length of the text depends on category where compatible item is used. Should be used in categories where TEXT version of compatible list is supported. See <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\"> supported-categories</a> resource. <a href=\"../../compatibility_list\" target=\"_blank\">Read more</a>.  # noqa: E501

        :return: The text of this CompatibilityListTextItem.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this CompatibilityListTextItem.

        Text description of the compatible item. Maximum length of the text depends on category where compatible item is used. Should be used in categories where TEXT version of compatible list is supported. See <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\"> supported-categories</a> resource. <a href=\"../../compatibility_list\" target=\"_blank\">Read more</a>.  # noqa: E501

        :param text: The text of this CompatibilityListTextItem.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompatibilityListTextItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompatibilityListTextItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CommandTask(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'field': 'str',
        'finished_at': 'datetime',
        'message': 'str',
        'offer': 'OfferId',
        'scheduled_at': 'datetime',
        'status': 'str',
        'errors': 'list[Error]'
    }

    attribute_map = {
        'field': 'field',
        'finished_at': 'finishedAt',
        'message': 'message',
        'offer': 'offer',
        'scheduled_at': 'scheduledAt',
        'status': 'status',
        'errors': 'errors'
    }

    def __init__(self, field=None, finished_at=None, message=None, offer=None, scheduled_at=None, status=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """CommandTask - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._field = None
        self._finished_at = None
        self._message = None
        self._offer = None
        self._scheduled_at = None
        self._status = None
        self._errors = None
        self.discriminator = None

        if field is not None:
            self.field = field
        if finished_at is not None:
            self.finished_at = finished_at
        if message is not None:
            self.message = message
        if offer is not None:
            self.offer = offer
        if scheduled_at is not None:
            self.scheduled_at = scheduled_at
        if status is not None:
            self.status = status
        if errors is not None:
            self.errors = errors

    @property
    def field(self):
        """Gets the field of this CommandTask.  # noqa: E501

        Modified field as JSON path.  # noqa: E501

        :return: The field of this CommandTask.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this CommandTask.

        Modified field as JSON path.  # noqa: E501

        :param field: The field of this CommandTask.  # noqa: E501
        :type: str
        """

        self._field = field

    @property
    def finished_at(self):
        """Gets the finished_at of this CommandTask.  # noqa: E501

        Date of completion of the modification. Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ  # noqa: E501

        :return: The finished_at of this CommandTask.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this CommandTask.

        Date of completion of the modification. Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ  # noqa: E501

        :param finished_at: The finished_at of this CommandTask.  # noqa: E501
        :type: datetime
        """

        self._finished_at = finished_at

    @property
    def message(self):
        """Gets the message of this CommandTask.  # noqa: E501

        General fail reason. You should check the errors structure to get more detailed information of the encountered errors.  # noqa: E501

        :return: The message of this CommandTask.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this CommandTask.

        General fail reason. You should check the errors structure to get more detailed information of the encountered errors.  # noqa: E501

        :param message: The message of this CommandTask.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def offer(self):
        """Gets the offer of this CommandTask.  # noqa: E501


        :return: The offer of this CommandTask.  # noqa: E501
        :rtype: OfferId
        """
        return self._offer

    @offer.setter
    def offer(self, offer):
        """Sets the offer of this CommandTask.


        :param offer: The offer of this CommandTask.  # noqa: E501
        :type: OfferId
        """

        self._offer = offer

    @property
    def scheduled_at(self):
        """Gets the scheduled_at of this CommandTask.  # noqa: E501

        Date of the modification schedule. Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ  # noqa: E501

        :return: The scheduled_at of this CommandTask.  # noqa: E501
        :rtype: datetime
        """
        return self._scheduled_at

    @scheduled_at.setter
    def scheduled_at(self, scheduled_at):
        """Sets the scheduled_at of this CommandTask.

        Date of the modification schedule. Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ  # noqa: E501

        :param scheduled_at: The scheduled_at of this CommandTask.  # noqa: E501
        :type: datetime
        """

        self._scheduled_at = scheduled_at

    @property
    def status(self):
        """Gets the status of this CommandTask.  # noqa: E501

        Available statuses: NEW, SUCCESS, FAIL  # noqa: E501

        :return: The status of this CommandTask.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CommandTask.

        Available statuses: NEW, SUCCESS, FAIL  # noqa: E501

        :param status: The status of this CommandTask.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def errors(self):
        """Gets the errors of this CommandTask.  # noqa: E501

        The list of error objects explaining the problems with command processing for the given offer.  # noqa: E501

        :return: The errors of this CommandTask.  # noqa: E501
        :rtype: list[Error]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this CommandTask.

        The list of error objects explaining the problems with command processing for the given offer.  # noqa: E501

        :param errors: The errors of this CommandTask.  # noqa: E501
        :type: list[Error]
        """

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommandTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CommandTask):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.sale_product_dto import SaleProductDto  # noqa: E501
from allegro_api.rest import ApiException

class TestSaleProductDto(unittest.TestCase):
    """SaleProductDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SaleProductDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.sale_product_dto.SaleProductDto()  # noqa: E501
        if include_optional :
            return SaleProductDto(
                id = 'c9e39cae-9cb6-11e9-a2a3-2a2ae2dbcce4', 
                name = 'iPhone 5s', 
                category = allegro_api.models.category.Category(
                    id = '0', ), 
                eans = ["0019062113399","0000007905193"], 
                images = [
                    allegro_api.models.image_url.ImageUrl(
                        url = '0', )
                    ], 
                parameters = [
                    allegro_api.models.product_parameter.ProductParameter(
                        id = '0', 
                        range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                            from = '0', 
                            to = '0', ), 
                        values = [
                            '0'
                            ], 
                        values_ids = [
                            '0'
                            ], 
                        values_labels = [
                            '0'
                            ], 
                        unit = '0', 
                        options = [
                            allegro_api.models.product_parameter_options.ProductParameter_options(
                                identifies_product = True, )
                            ], )
                    ], 
                offer_requirements = allegro_api.models.offer_requirements.OfferRequirements(
                    parameters = [
                        allegro_api.models.product_parameter.ProductParameter(
                            id = '0', 
                            range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                from = '0', 
                                to = '0', ), 
                            values = [
                                '0'
                                ], 
                            values_ids = [
                                '0'
                                ], 
                            values_labels = [
                                '0'
                                ], 
                            unit = '0', 
                            options = [
                                allegro_api.models.product_parameter_options.ProductParameter_options(
                                    identifies_product = True, )
                                ], )
                        ], ), 
                compatibility_list = allegro_api.models.sale_product_compatibility_list.SaleProductCompatibilityList(
                    id = '460b2511-b786-47b9-9d7e-1f868728cfd6-f103931434fbf4aa06764f3df74d371df23aa138a9cd46dbe570f51af79db1c4-2', 
                    type = 'PRODUCT_BASED', 
                    items = [
                        allegro_api.models.compatibility_list_item_product_based.CompatibilityListItemProductBased(
                            text = 'AUDI 90 (89, 89Q, 8A, B3) 1988/06-1991/09 2.3 E 20V quattro 170KM/125kW 1501', )
                        ], ), 
                tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                    id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', 
                    items = [
                        allegro_api.models.tecdoc_specification_item.TecdocSpecificationItem(
                            name = 'Wersja TecDoc', 
                            values = ["0319"], )
                        ], ), 
                description = allegro_api.models.standardized_description.StandardizedDescription(
                    sections = [
                        allegro_api.models.description_section.DescriptionSection(
                            items = [
                                allegro_api.models.description_section_item.DescriptionSectionItem(
                                    type = '0', )
                                ], )
                        ], )
            )
        else :
            return SaleProductDto(
                id = 'c9e39cae-9cb6-11e9-a2a3-2a2ae2dbcce4',
                name = 'iPhone 5s',
                category = allegro_api.models.category.Category(
                    id = '0', ),
        )

    def testSaleProductDto(self):
        """Test SaleProductDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.public_table_dto import PublicTableDto  # noqa: E501
from allegro_api.rest import ApiException

class TestPublicTableDto(unittest.TestCase):
    """PublicTableDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PublicTableDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.public_table_dto.PublicTableDto()  # noqa: E501
        if include_optional :
            return PublicTableDto(
                headers = [
                    allegro_api.models.header.Header(
                        name = '0', )
                    ], 
                id = '0', 
                image = allegro_api.models.public_table_image_dto.PublicTableImageDto(
                    captions = [
                        allegro_api.models.caption.Caption(
                            index = '0', 
                            value = '0', )
                        ], 
                    url = '0', ), 
                name = '0', 
                orientation = 'HORIZONTAL', 
                values = [
                    allegro_api.models.cells.Cells(
                        cells = [
                            '0'
                            ], )
                    ]
            )
        else :
            return PublicTableDto(
                headers = [
                    allegro_api.models.header.Header(
                        name = '0', )
                    ],
                name = '0',
                orientation = 'HORIZONTAL',
                values = [
                    allegro_api.models.cells.Cells(
                        cells = [
                            '0'
                            ], )
                    ],
        )

    def testPublicTableDto(self):
        """Test PublicTableDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Dispute(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'subject': 'Subject',
        'status': 'str',
        'buyer': 'DisputeUser',
        'seller': 'DisputeUser',
        'checkout_form': 'DisputeCheckoutForm',
        'message': 'DisputeFirstMessage',
        'messages_count': 'int'
    }

    attribute_map = {
        'id': 'id',
        'subject': 'subject',
        'status': 'status',
        'buyer': 'buyer',
        'seller': 'seller',
        'checkout_form': 'checkoutForm',
        'message': 'message',
        'messages_count': 'messagesCount'
    }

    def __init__(self, id=None, subject=None, status=None, buyer=None, seller=None, checkout_form=None, message=None, messages_count=None, local_vars_configuration=None):  # noqa: E501
        """Dispute - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._subject = None
        self._status = None
        self._buyer = None
        self._seller = None
        self._checkout_form = None
        self._message = None
        self._messages_count = None
        self.discriminator = None

        self.id = id
        self.subject = subject
        self.status = status
        self.buyer = buyer
        self.seller = seller
        self.checkout_form = checkout_form
        self.message = message
        self.messages_count = messages_count

    @property
    def id(self):
        """Gets the id of this Dispute.  # noqa: E501

        Identifier of the dispute  # noqa: E501

        :return: The id of this Dispute.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Dispute.

        Identifier of the dispute  # noqa: E501

        :param id: The id of this Dispute.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def subject(self):
        """Gets the subject of this Dispute.  # noqa: E501


        :return: The subject of this Dispute.  # noqa: E501
        :rtype: Subject
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this Dispute.


        :param subject: The subject of this Dispute.  # noqa: E501
        :type: Subject
        """
        if self.local_vars_configuration.client_side_validation and subject is None:  # noqa: E501
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def status(self):
        """Gets the status of this Dispute.  # noqa: E501


        :return: The status of this Dispute.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Dispute.


        :param status: The status of this Dispute.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["CLOSED", "ONGOING", "UNRESOLVED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def buyer(self):
        """Gets the buyer of this Dispute.  # noqa: E501


        :return: The buyer of this Dispute.  # noqa: E501
        :rtype: DisputeUser
        """
        return self._buyer

    @buyer.setter
    def buyer(self, buyer):
        """Sets the buyer of this Dispute.


        :param buyer: The buyer of this Dispute.  # noqa: E501
        :type: DisputeUser
        """
        if self.local_vars_configuration.client_side_validation and buyer is None:  # noqa: E501
            raise ValueError("Invalid value for `buyer`, must not be `None`")  # noqa: E501

        self._buyer = buyer

    @property
    def seller(self):
        """Gets the seller of this Dispute.  # noqa: E501


        :return: The seller of this Dispute.  # noqa: E501
        :rtype: DisputeUser
        """
        return self._seller

    @seller.setter
    def seller(self, seller):
        """Sets the seller of this Dispute.


        :param seller: The seller of this Dispute.  # noqa: E501
        :type: DisputeUser
        """
        if self.local_vars_configuration.client_side_validation and seller is None:  # noqa: E501
            raise ValueError("Invalid value for `seller`, must not be `None`")  # noqa: E501

        self._seller = seller

    @property
    def checkout_form(self):
        """Gets the checkout_form of this Dispute.  # noqa: E501


        :return: The checkout_form of this Dispute.  # noqa: E501
        :rtype: DisputeCheckoutForm
        """
        return self._checkout_form

    @checkout_form.setter
    def checkout_form(self, checkout_form):
        """Sets the checkout_form of this Dispute.


        :param checkout_form: The checkout_form of this Dispute.  # noqa: E501
        :type: DisputeCheckoutForm
        """
        if self.local_vars_configuration.client_side_validation and checkout_form is None:  # noqa: E501
            raise ValueError("Invalid value for `checkout_form`, must not be `None`")  # noqa: E501

        self._checkout_form = checkout_form

    @property
    def message(self):
        """Gets the message of this Dispute.  # noqa: E501


        :return: The message of this Dispute.  # noqa: E501
        :rtype: DisputeFirstMessage
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Dispute.


        :param message: The message of this Dispute.  # noqa: E501
        :type: DisputeFirstMessage
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def messages_count(self):
        """Gets the messages_count of this Dispute.  # noqa: E501


        :return: The messages_count of this Dispute.  # noqa: E501
        :rtype: int
        """
        return self._messages_count

    @messages_count.setter
    def messages_count(self, messages_count):
        """Sets the messages_count of this Dispute.


        :param messages_count: The messages_count of this Dispute.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and messages_count is None:  # noqa: E501
            raise ValueError("Invalid value for `messages_count`, must not be `None`")  # noqa: E501

        self._messages_count = messages_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Dispute):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Dispute):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class OrderManagementApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_order_shipments_using_post(self, id, checkout_form_add_waybill_request, **kwargs):  # noqa: E501
        """Add a parcel tracking number  # noqa: E501

        Add a parcel tracking number (shipment) to given order line items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_order_shipments_using_post(id, checkout_form_add_waybill_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Order identifier. (required)
        :param CheckoutFormAddWaybillRequest checkout_form_add_waybill_request: request (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CheckoutFormAddWaybillCreated
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_order_shipments_using_post_with_http_info(id, checkout_form_add_waybill_request, **kwargs)  # noqa: E501

    def create_order_shipments_using_post_with_http_info(self, id, checkout_form_add_waybill_request, **kwargs):  # noqa: E501
        """Add a parcel tracking number  # noqa: E501

        Add a parcel tracking number (shipment) to given order line items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_order_shipments_using_post_with_http_info(id, checkout_form_add_waybill_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Order identifier. (required)
        :param CheckoutFormAddWaybillRequest checkout_form_add_waybill_request: request (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CheckoutFormAddWaybillCreated, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id', 'checkout_form_add_waybill_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_order_shipments_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `create_order_shipments_using_post`")  # noqa: E501
        # verify the required parameter 'checkout_form_add_waybill_request' is set
        if self.api_client.client_side_validation and ('checkout_form_add_waybill_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['checkout_form_add_waybill_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `checkout_form_add_waybill_request` when calling `create_order_shipments_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'checkout_form_add_waybill_request' in local_var_params:
            body_params = local_var_params['checkout_form_add_waybill_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/checkout-forms/{id}/shipments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckoutFormAddWaybillCreated',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_mapping(self, **kwargs):  # noqa: E501
        """Get mapping for line item id  # noqa: E501

        Allows mapping identifiers from dealId to lineItemId and vice-versa. One of defined query parameters has to be provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_mapping(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str line_item_id: Line item identifier.
        :param str deal_id: Deal identifier.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LineItemIdMappings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_mapping_with_http_info(**kwargs)  # noqa: E501

    def find_mapping_with_http_info(self, **kwargs):  # noqa: E501
        """Get mapping for line item id  # noqa: E501

        Allows mapping identifiers from dealId to lineItemId and vice-versa. One of defined query parameters has to be provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_mapping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str line_item_id: Line item identifier.
        :param str deal_id: Deal identifier.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LineItemIdMappings, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['line_item_id', 'deal_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_mapping" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'line_item_id' in local_var_params and local_var_params['line_item_id'] is not None:  # noqa: E501
            query_params.append(('lineItemId', local_var_params['line_item_id']))  # noqa: E501
        if 'deal_id' in local_var_params and local_var_params['deal_id'] is not None:  # noqa: E501
            query_params.append(('dealId', local_var_params['deal_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/line-item-id-mappings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LineItemIdMappings',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_list_of_orders_using_get(self, **kwargs):  # noqa: E501
        """Get the user's orders  # noqa: E501

        Use this resource to get an order list. <a href=\"/orders/#03\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_of_orders_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: Index of first returned checkout-form from all search results.
        :param int limit: Maximum number of checkout-forms in response.
        :param str status: Specify status value that checkout-forms must have to be included in the output. Allowed values are:   * `BOUGHT`: purchase without checkout form filled in.   * `FILLED_IN`: checkout form filled in but payment is not completed yet so data could still change.   * `READY_FOR_PROCESSING`: payment completed. Purchase is ready for processing.
        :param str fulfillment_status: Specify seller status value that checkout-forms must have to be included in the output. Allowed values are:   * `NEW`   * `PROCESSING`   * `READY_FOR_SHIPMENT`   * `SENT`   * `CANCELLED`.
        :param str fulfillment_shipment_summary_line_items_sent: Specify filter for line items sending status. Allowed values are:   * `NONE`: none of line items have tracking number specified   * `SOME`: some of line items have tracking number specified   * `ALL`: all of line items have tracking number specified.
        :param datetime line_items_bought_at_lte: Latest line item bought date. The upper bound of date time range from which checkout forms will be taken.
        :param datetime line_items_bought_at_gte: Latest line item bought date. The lower bound of date time range from which checkout forms will be taken.
        :param str payment_id: Find checkout-forms having specified payment id.
        :param str surcharges_id: Find checkout-forms having specified surcharge id.
        :param str delivery_method_id: Find checkout-forms having specified delivery method id.
        :param str buyer_login: Find checkout-forms having specified buyer login.
        :param datetime updated_at_lte: Checkout form last modification date. The upper bound of date time range from which checkout forms will be taken.
        :param datetime updated_at_gte: Checkout form last modification date. The lower bound of date time range from which checkout forms will be taken.
        :param str sort: The results' sorting order. No prefix in the value means ascending order. `-` prefix means descending order. If you don't provide the sort parameter, the list is sorted by line item boughtAt date, descending.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CheckoutForms
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_list_of_orders_using_get_with_http_info(**kwargs)  # noqa: E501

    def get_list_of_orders_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get the user's orders  # noqa: E501

        Use this resource to get an order list. <a href=\"/orders/#03\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_of_orders_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: Index of first returned checkout-form from all search results.
        :param int limit: Maximum number of checkout-forms in response.
        :param str status: Specify status value that checkout-forms must have to be included in the output. Allowed values are:   * `BOUGHT`: purchase without checkout form filled in.   * `FILLED_IN`: checkout form filled in but payment is not completed yet so data could still change.   * `READY_FOR_PROCESSING`: payment completed. Purchase is ready for processing.
        :param str fulfillment_status: Specify seller status value that checkout-forms must have to be included in the output. Allowed values are:   * `NEW`   * `PROCESSING`   * `READY_FOR_SHIPMENT`   * `SENT`   * `CANCELLED`.
        :param str fulfillment_shipment_summary_line_items_sent: Specify filter for line items sending status. Allowed values are:   * `NONE`: none of line items have tracking number specified   * `SOME`: some of line items have tracking number specified   * `ALL`: all of line items have tracking number specified.
        :param datetime line_items_bought_at_lte: Latest line item bought date. The upper bound of date time range from which checkout forms will be taken.
        :param datetime line_items_bought_at_gte: Latest line item bought date. The lower bound of date time range from which checkout forms will be taken.
        :param str payment_id: Find checkout-forms having specified payment id.
        :param str surcharges_id: Find checkout-forms having specified surcharge id.
        :param str delivery_method_id: Find checkout-forms having specified delivery method id.
        :param str buyer_login: Find checkout-forms having specified buyer login.
        :param datetime updated_at_lte: Checkout form last modification date. The upper bound of date time range from which checkout forms will be taken.
        :param datetime updated_at_gte: Checkout form last modification date. The lower bound of date time range from which checkout forms will be taken.
        :param str sort: The results' sorting order. No prefix in the value means ascending order. `-` prefix means descending order. If you don't provide the sort parameter, the list is sorted by line item boughtAt date, descending.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CheckoutForms, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offset', 'limit', 'status', 'fulfillment_status', 'fulfillment_shipment_summary_line_items_sent', 'line_items_bought_at_lte', 'line_items_bought_at_gte', 'payment_id', 'surcharges_id', 'delivery_method_id', 'buyer_login', 'updated_at_lte', 'updated_at_gte', 'sort']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_list_of_orders_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_list_of_orders_using_get`, must be a value greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_list_of_orders_using_get`, must be a value less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_list_of_orders_using_get`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'status' in local_var_params and local_var_params['status'] is not None:  # noqa: E501
            query_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'fulfillment_status' in local_var_params and local_var_params['fulfillment_status'] is not None:  # noqa: E501
            query_params.append(('fulfillment.status', local_var_params['fulfillment_status']))  # noqa: E501
        if 'fulfillment_shipment_summary_line_items_sent' in local_var_params and local_var_params['fulfillment_shipment_summary_line_items_sent'] is not None:  # noqa: E501
            query_params.append(('fulfillment.shipmentSummary.lineItemsSent', local_var_params['fulfillment_shipment_summary_line_items_sent']))  # noqa: E501
        if 'line_items_bought_at_lte' in local_var_params and local_var_params['line_items_bought_at_lte'] is not None:  # noqa: E501
            query_params.append(('lineItems.boughtAt.lte', local_var_params['line_items_bought_at_lte']))  # noqa: E501
        if 'line_items_bought_at_gte' in local_var_params and local_var_params['line_items_bought_at_gte'] is not None:  # noqa: E501
            query_params.append(('lineItems.boughtAt.gte', local_var_params['line_items_bought_at_gte']))  # noqa: E501
        if 'payment_id' in local_var_params and local_var_params['payment_id'] is not None:  # noqa: E501
            query_params.append(('payment.id', local_var_params['payment_id']))  # noqa: E501
        if 'surcharges_id' in local_var_params and local_var_params['surcharges_id'] is not None:  # noqa: E501
            query_params.append(('surcharges.id', local_var_params['surcharges_id']))  # noqa: E501
        if 'delivery_method_id' in local_var_params and local_var_params['delivery_method_id'] is not None:  # noqa: E501
            query_params.append(('delivery.method.id', local_var_params['delivery_method_id']))  # noqa: E501
        if 'buyer_login' in local_var_params and local_var_params['buyer_login'] is not None:  # noqa: E501
            query_params.append(('buyer.login', local_var_params['buyer_login']))  # noqa: E501
        if 'updated_at_lte' in local_var_params and local_var_params['updated_at_lte'] is not None:  # noqa: E501
            query_params.append(('updatedAt.lte', local_var_params['updated_at_lte']))  # noqa: E501
        if 'updated_at_gte' in local_var_params and local_var_params['updated_at_gte'] is not None:  # noqa: E501
            query_params.append(('updatedAt.gte', local_var_params['updated_at_gte']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/checkout-forms', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckoutForms',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_order_events_statistics_using_get(self, **kwargs):  # noqa: E501
        """Get order events statistics  # noqa: E501

        Use this resource to returns object that contains event id and occurrence date of the latest event. It gives you current starting point for reading events. <a href=\"/orders/#02\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_events_statistics_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OrderEventStats
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_order_events_statistics_using_get_with_http_info(**kwargs)  # noqa: E501

    def get_order_events_statistics_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get order events statistics  # noqa: E501

        Use this resource to returns object that contains event id and occurrence date of the latest event. It gives you current starting point for reading events. <a href=\"/orders/#02\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_events_statistics_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OrderEventStats, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order_events_statistics_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/event-stats', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrderEventStats',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_order_events_using_get(self, **kwargs):  # noqa: E501
        """Get order events  # noqa: E501

        Use this resource to return events that allow you to monitor actions which clients perform, i.e. making a purchase, filling in the checkout form (FOD), finishing payment process, making a surcharge. <a href=\"/orders/#02\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_events_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str _from: You can use the event ID to retrieve subsequent chunks of events.
        :param list[str] type: Specify array of event types for filtering. Allowed values are:   * `BOUGHT`: purchase without checkout form filled in   * `FILLED_IN`: checkout form filled in but payment is not completed yet so data could still change   * `READY_FOR_PROCESSING`: payment completed. Purchase is ready for processing   * `FULFILLMENT_STATUS_CHANGED`: fulfillment status changed.
        :param int limit: The maximum number of events returned in the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OrderEventsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_order_events_using_get_with_http_info(**kwargs)  # noqa: E501

    def get_order_events_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get order events  # noqa: E501

        Use this resource to return events that allow you to monitor actions which clients perform, i.e. making a purchase, filling in the checkout form (FOD), finishing payment process, making a surcharge. <a href=\"/orders/#02\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_events_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str _from: You can use the event ID to retrieve subsequent chunks of events.
        :param list[str] type: Specify array of event types for filtering. Allowed values are:   * `BOUGHT`: purchase without checkout form filled in   * `FILLED_IN`: checkout form filled in but payment is not completed yet so data could still change   * `READY_FOR_PROCESSING`: payment completed. Purchase is ready for processing   * `FULFILLMENT_STATUS_CHANGED`: fulfillment status changed.
        :param int limit: The maximum number of events returned in the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OrderEventsList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['_from', 'type', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order_events_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_order_events_using_get`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_order_events_using_get`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in local_var_params and local_var_params['_from'] is not None:  # noqa: E501
            query_params.append(('from', local_var_params['_from']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501
            collection_formats['type'] = 'multi'  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrderEventsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_order_shipments_using_get(self, id, **kwargs):  # noqa: E501
        """Get a list of parcel tracking numbers  # noqa: E501

        Get a list of parcel tracking numbers currently assigned to the order. Orders can be retrieved using REST API resource GET /order/checkout-forms. Please note that the shipment list may contain parcel tracking numbers added through other channels such as Moje Allegro or by the carrier that delivers the parcel.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_shipments_using_get(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Order identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CheckoutFormOrderWaybillResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_order_shipments_using_get_with_http_info(id, **kwargs)  # noqa: E501

    def get_order_shipments_using_get_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a list of parcel tracking numbers  # noqa: E501

        Get a list of parcel tracking numbers currently assigned to the order. Orders can be retrieved using REST API resource GET /order/checkout-forms. Please note that the shipment list may contain parcel tracking numbers added through other channels such as Moje Allegro or by the carrier that delivers the parcel.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_shipments_using_get_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Order identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CheckoutFormOrderWaybillResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order_shipments_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_order_shipments_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/checkout-forms/{id}/shipments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckoutFormOrderWaybillResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_orders_details_using_get(self, id, **kwargs):  # noqa: E501
        """Get an order's details  # noqa: E501

        Use this resource to get an order details. <a href=\"/orders/#04\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_orders_details_using_get(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Checkout form identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CheckoutForm
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_orders_details_using_get_with_http_info(id, **kwargs)  # noqa: E501

    def get_orders_details_using_get_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get an order's details  # noqa: E501

        Use this resource to get an order details. <a href=\"/orders/#04\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_orders_details_using_get_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Checkout form identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CheckoutForm, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orders_details_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_orders_details_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/checkout-forms/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckoutForm',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_order_fulfillment_using_put(self, id, checkout_form_fulfillment, **kwargs):  # noqa: E501
        """Set seller order status  # noqa: E501

        Use to set seller order status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_order_fulfillment_using_put(id, checkout_form_fulfillment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Order identifier. (required)
        :param CheckoutFormFulfillment checkout_form_fulfillment: request (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.set_order_fulfillment_using_put_with_http_info(id, checkout_form_fulfillment, **kwargs)  # noqa: E501

    def set_order_fulfillment_using_put_with_http_info(self, id, checkout_form_fulfillment, **kwargs):  # noqa: E501
        """Set seller order status  # noqa: E501

        Use to set seller order status.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_order_fulfillment_using_put_with_http_info(id, checkout_form_fulfillment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Order identifier. (required)
        :param CheckoutFormFulfillment checkout_form_fulfillment: request (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['id', 'checkout_form_fulfillment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_order_fulfillment_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `set_order_fulfillment_using_put`")  # noqa: E501
        # verify the required parameter 'checkout_form_fulfillment' is set
        if self.api_client.client_side_validation and ('checkout_form_fulfillment' not in local_var_params or  # noqa: E501
                                                        local_var_params['checkout_form_fulfillment'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `checkout_form_fulfillment` when calling `set_order_fulfillment_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'checkout_form_fulfillment' in local_var_params:
            body_params = local_var_params['checkout_form_fulfillment']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/order/checkout-forms/{id}/fulfillment', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class BaseOperation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'group': 'str',
        'wallet': 'Wallet',
        'value': 'OperationValue',
        'occurred_at': 'datetime'
    }

    attribute_map = {
        'type': 'type',
        'group': 'group',
        'wallet': 'wallet',
        'value': 'value',
        'occurred_at': 'occurredAt'
    }

    discriminator_value_class_map = {
        'RefundIncreaseOperation': 'RefundIncreaseOperation',
        'PayoutOperationCancel': 'PayoutOperationCancel',
        'RefundCancelOperation': 'RefundCancelOperation',
        'DeductionIncreaseOperation': 'DeductionIncreaseOperation',
        'PayoutOperation': 'PayoutOperation',
        'CorrectionOperation': 'CorrectionOperation',
        'SurchargeOperation': 'SurchargeOperation',
        'ContributionOperation': 'ContributionOperation',
        'RefundChargeOperation': 'RefundChargeOperation',
        'DeductionChargeOperation': 'DeductionChargeOperation'
    }

    def __init__(self, type=None, group=None, wallet=None, value=None, occurred_at=None, local_vars_configuration=None):  # noqa: E501
        """BaseOperation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._group = None
        self._wallet = None
        self._value = None
        self._occurred_at = None
        self.discriminator = 'type'

        self.type = type
        self.group = group
        self.wallet = wallet
        self.value = value
        self.occurred_at = occurred_at

    @property
    def type(self):
        """Gets the type of this BaseOperation.  # noqa: E501

        Type of the operation.  # noqa: E501

        :return: The type of this BaseOperation.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BaseOperation.

        Type of the operation.  # noqa: E501

        :param type: The type of this BaseOperation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def group(self):
        """Gets the group of this BaseOperation.  # noqa: E501

        The group to which the given operation type belongs.  # noqa: E501

        :return: The group of this BaseOperation.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this BaseOperation.

        The group to which the given operation type belongs.  # noqa: E501

        :param group: The group of this BaseOperation.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and group is None:  # noqa: E501
            raise ValueError("Invalid value for `group`, must not be `None`")  # noqa: E501
        allowed_values = ["INCOME", "OUTCOME", "REFUND"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and group not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `group` ({0}), must be one of {1}"  # noqa: E501
                .format(group, allowed_values)
            )

        self._group = group

    @property
    def wallet(self):
        """Gets the wallet of this BaseOperation.  # noqa: E501


        :return: The wallet of this BaseOperation.  # noqa: E501
        :rtype: Wallet
        """
        return self._wallet

    @wallet.setter
    def wallet(self, wallet):
        """Sets the wallet of this BaseOperation.


        :param wallet: The wallet of this BaseOperation.  # noqa: E501
        :type: Wallet
        """
        if self.local_vars_configuration.client_side_validation and wallet is None:  # noqa: E501
            raise ValueError("Invalid value for `wallet`, must not be `None`")  # noqa: E501

        self._wallet = wallet

    @property
    def value(self):
        """Gets the value of this BaseOperation.  # noqa: E501


        :return: The value of this BaseOperation.  # noqa: E501
        :rtype: OperationValue
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this BaseOperation.


        :param value: The value of this BaseOperation.  # noqa: E501
        :type: OperationValue
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def occurred_at(self):
        """Gets the occurred_at of this BaseOperation.  # noqa: E501

        Date and time of the operation in ISO 8601 format.  # noqa: E501

        :return: The occurred_at of this BaseOperation.  # noqa: E501
        :rtype: datetime
        """
        return self._occurred_at

    @occurred_at.setter
    def occurred_at(self, occurred_at):
        """Sets the occurred_at of this BaseOperation.

        Date and time of the operation in ISO 8601 format.  # noqa: E501

        :param occurred_at: The occurred_at of this BaseOperation.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and occurred_at is None:  # noqa: E501
            raise ValueError("Invalid value for `occurred_at`, must not be `None`")  # noqa: E501

        self._occurred_at = occurred_at

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_key = self.attribute_map[self.discriminator]
        discriminator_value = data[discriminator_key]
        return self.discriminator_value_class_map.get(discriminator_value)

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseOperation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BaseOperation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CheckoutFormDeliveryReference(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'address': 'CheckoutFormDeliveryAddress',
        'method': 'CheckoutFormDeliveryMethod',
        'pickup_point': 'CheckoutFormDeliveryPickupPoint',
        'cost': 'Price',
        'time': 'CheckoutFormDeliveryTime',
        'smart': 'bool',
        'calculated_number_of_packages': 'int'
    }

    attribute_map = {
        'address': 'address',
        'method': 'method',
        'pickup_point': 'pickupPoint',
        'cost': 'cost',
        'time': 'time',
        'smart': 'smart',
        'calculated_number_of_packages': 'calculatedNumberOfPackages'
    }

    def __init__(self, address=None, method=None, pickup_point=None, cost=None, time=None, smart=None, calculated_number_of_packages=None, local_vars_configuration=None):  # noqa: E501
        """CheckoutFormDeliveryReference - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._address = None
        self._method = None
        self._pickup_point = None
        self._cost = None
        self._time = None
        self._smart = None
        self._calculated_number_of_packages = None
        self.discriminator = None

        if address is not None:
            self.address = address
        if method is not None:
            self.method = method
        if pickup_point is not None:
            self.pickup_point = pickup_point
        if cost is not None:
            self.cost = cost
        if time is not None:
            self.time = time
        if smart is not None:
            self.smart = smart
        if calculated_number_of_packages is not None:
            self.calculated_number_of_packages = calculated_number_of_packages

    @property
    def address(self):
        """Gets the address of this CheckoutFormDeliveryReference.  # noqa: E501


        :return: The address of this CheckoutFormDeliveryReference.  # noqa: E501
        :rtype: CheckoutFormDeliveryAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this CheckoutFormDeliveryReference.


        :param address: The address of this CheckoutFormDeliveryReference.  # noqa: E501
        :type: CheckoutFormDeliveryAddress
        """

        self._address = address

    @property
    def method(self):
        """Gets the method of this CheckoutFormDeliveryReference.  # noqa: E501


        :return: The method of this CheckoutFormDeliveryReference.  # noqa: E501
        :rtype: CheckoutFormDeliveryMethod
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this CheckoutFormDeliveryReference.


        :param method: The method of this CheckoutFormDeliveryReference.  # noqa: E501
        :type: CheckoutFormDeliveryMethod
        """

        self._method = method

    @property
    def pickup_point(self):
        """Gets the pickup_point of this CheckoutFormDeliveryReference.  # noqa: E501


        :return: The pickup_point of this CheckoutFormDeliveryReference.  # noqa: E501
        :rtype: CheckoutFormDeliveryPickupPoint
        """
        return self._pickup_point

    @pickup_point.setter
    def pickup_point(self, pickup_point):
        """Sets the pickup_point of this CheckoutFormDeliveryReference.


        :param pickup_point: The pickup_point of this CheckoutFormDeliveryReference.  # noqa: E501
        :type: CheckoutFormDeliveryPickupPoint
        """

        self._pickup_point = pickup_point

    @property
    def cost(self):
        """Gets the cost of this CheckoutFormDeliveryReference.  # noqa: E501


        :return: The cost of this CheckoutFormDeliveryReference.  # noqa: E501
        :rtype: Price
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this CheckoutFormDeliveryReference.


        :param cost: The cost of this CheckoutFormDeliveryReference.  # noqa: E501
        :type: Price
        """

        self._cost = cost

    @property
    def time(self):
        """Gets the time of this CheckoutFormDeliveryReference.  # noqa: E501


        :return: The time of this CheckoutFormDeliveryReference.  # noqa: E501
        :rtype: CheckoutFormDeliveryTime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this CheckoutFormDeliveryReference.


        :param time: The time of this CheckoutFormDeliveryReference.  # noqa: E501
        :type: CheckoutFormDeliveryTime
        """

        self._time = time

    @property
    def smart(self):
        """Gets the smart of this CheckoutFormDeliveryReference.  # noqa: E501

        Buyer used a SMART option  # noqa: E501

        :return: The smart of this CheckoutFormDeliveryReference.  # noqa: E501
        :rtype: bool
        """
        return self._smart

    @smart.setter
    def smart(self, smart):
        """Sets the smart of this CheckoutFormDeliveryReference.

        Buyer used a SMART option  # noqa: E501

        :param smart: The smart of this CheckoutFormDeliveryReference.  # noqa: E501
        :type: bool
        """

        self._smart = smart

    @property
    def calculated_number_of_packages(self):
        """Gets the calculated_number_of_packages of this CheckoutFormDeliveryReference.  # noqa: E501

        Calculated number of packages.  # noqa: E501

        :return: The calculated_number_of_packages of this CheckoutFormDeliveryReference.  # noqa: E501
        :rtype: int
        """
        return self._calculated_number_of_packages

    @calculated_number_of_packages.setter
    def calculated_number_of_packages(self, calculated_number_of_packages):
        """Sets the calculated_number_of_packages of this CheckoutFormDeliveryReference.

        Calculated number of packages.  # noqa: E501

        :param calculated_number_of_packages: The calculated_number_of_packages of this CheckoutFormDeliveryReference.  # noqa: E501
        :type: int
        """

        self._calculated_number_of_packages = calculated_number_of_packages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckoutFormDeliveryReference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckoutFormDeliveryReference):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.payment_operations import PaymentOperations  # noqa: E501
from allegro_api.rest import ApiException

class TestPaymentOperations(unittest.TestCase):
    """PaymentOperations unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaymentOperations
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.payment_operations.PaymentOperations()  # noqa: E501
        if include_optional :
            return PaymentOperations(
                payment_operations = [
                    allegro_api.models.base_operation.BaseOperation(
                        type = '0', 
                        group = 'INCOME', 
                        wallet = allegro_api.models.wallet.Wallet(
                            payment_operator = 'PAYU', 
                            type = 'AVAILABLE', 
                            balance = null, ), 
                        value = null, 
                        occurred_at = '2019-05-08T09:45:00.818Z', )
                    ], 
                count = 50, 
                total_count = 123
            )
        else :
            return PaymentOperations(
                payment_operations = [
                    allegro_api.models.base_operation.BaseOperation(
                        type = '0', 
                        group = 'INCOME', 
                        wallet = allegro_api.models.wallet.Wallet(
                            payment_operator = 'PAYU', 
                            type = 'AVAILABLE', 
                            balance = null, ), 
                        value = null, 
                        occurred_at = '2019-05-08T09:45:00.818Z', )
                    ],
                count = 50,
                total_count = 123,
        )

    def testPaymentOperations(self):
        """Test PaymentOperations"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ListingOffer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'seller': 'OfferSeller',
        'promotion': 'OfferPromotion',
        'delivery': 'OfferDelivery',
        'images': 'list[OfferImages]',
        'selling_mode': 'OfferSellingMode',
        'stock': 'OfferStock',
        'vendor': 'OfferVendor',
        'category': 'OfferCategory',
        'publication': 'OfferPublication'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'seller': 'seller',
        'promotion': 'promotion',
        'delivery': 'delivery',
        'images': 'images',
        'selling_mode': 'sellingMode',
        'stock': 'stock',
        'vendor': 'vendor',
        'category': 'category',
        'publication': 'publication'
    }

    def __init__(self, id=None, name=None, seller=None, promotion=None, delivery=None, images=None, selling_mode=None, stock=None, vendor=None, category=None, publication=None, local_vars_configuration=None):  # noqa: E501
        """ListingOffer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._seller = None
        self._promotion = None
        self._delivery = None
        self._images = None
        self._selling_mode = None
        self._stock = None
        self._vendor = None
        self._category = None
        self._publication = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if seller is not None:
            self.seller = seller
        if promotion is not None:
            self.promotion = promotion
        if delivery is not None:
            self.delivery = delivery
        if images is not None:
            self.images = images
        if selling_mode is not None:
            self.selling_mode = selling_mode
        if stock is not None:
            self.stock = stock
        if vendor is not None:
            self.vendor = vendor
        if category is not None:
            self.category = category
        if publication is not None:
            self.publication = publication

    @property
    def id(self):
        """Gets the id of this ListingOffer.  # noqa: E501

        The offer ID.  # noqa: E501

        :return: The id of this ListingOffer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListingOffer.

        The offer ID.  # noqa: E501

        :param id: The id of this ListingOffer.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ListingOffer.  # noqa: E501

        The title of the offer.  # noqa: E501

        :return: The name of this ListingOffer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListingOffer.

        The title of the offer.  # noqa: E501

        :param name: The name of this ListingOffer.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def seller(self):
        """Gets the seller of this ListingOffer.  # noqa: E501


        :return: The seller of this ListingOffer.  # noqa: E501
        :rtype: OfferSeller
        """
        return self._seller

    @seller.setter
    def seller(self, seller):
        """Sets the seller of this ListingOffer.


        :param seller: The seller of this ListingOffer.  # noqa: E501
        :type: OfferSeller
        """

        self._seller = seller

    @property
    def promotion(self):
        """Gets the promotion of this ListingOffer.  # noqa: E501


        :return: The promotion of this ListingOffer.  # noqa: E501
        :rtype: OfferPromotion
        """
        return self._promotion

    @promotion.setter
    def promotion(self, promotion):
        """Sets the promotion of this ListingOffer.


        :param promotion: The promotion of this ListingOffer.  # noqa: E501
        :type: OfferPromotion
        """

        self._promotion = promotion

    @property
    def delivery(self):
        """Gets the delivery of this ListingOffer.  # noqa: E501


        :return: The delivery of this ListingOffer.  # noqa: E501
        :rtype: OfferDelivery
        """
        return self._delivery

    @delivery.setter
    def delivery(self, delivery):
        """Sets the delivery of this ListingOffer.


        :param delivery: The delivery of this ListingOffer.  # noqa: E501
        :type: OfferDelivery
        """

        self._delivery = delivery

    @property
    def images(self):
        """Gets the images of this ListingOffer.  # noqa: E501

        The gallery of images. Only the URL of the original sized image is provided. The first image represents the thumbnail image used on listing.  # noqa: E501

        :return: The images of this ListingOffer.  # noqa: E501
        :rtype: list[OfferImages]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this ListingOffer.

        The gallery of images. Only the URL of the original sized image is provided. The first image represents the thumbnail image used on listing.  # noqa: E501

        :param images: The images of this ListingOffer.  # noqa: E501
        :type: list[OfferImages]
        """

        self._images = images

    @property
    def selling_mode(self):
        """Gets the selling_mode of this ListingOffer.  # noqa: E501


        :return: The selling_mode of this ListingOffer.  # noqa: E501
        :rtype: OfferSellingMode
        """
        return self._selling_mode

    @selling_mode.setter
    def selling_mode(self, selling_mode):
        """Sets the selling_mode of this ListingOffer.


        :param selling_mode: The selling_mode of this ListingOffer.  # noqa: E501
        :type: OfferSellingMode
        """

        self._selling_mode = selling_mode

    @property
    def stock(self):
        """Gets the stock of this ListingOffer.  # noqa: E501


        :return: The stock of this ListingOffer.  # noqa: E501
        :rtype: OfferStock
        """
        return self._stock

    @stock.setter
    def stock(self, stock):
        """Sets the stock of this ListingOffer.


        :param stock: The stock of this ListingOffer.  # noqa: E501
        :type: OfferStock
        """

        self._stock = stock

    @property
    def vendor(self):
        """Gets the vendor of this ListingOffer.  # noqa: E501


        :return: The vendor of this ListingOffer.  # noqa: E501
        :rtype: OfferVendor
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this ListingOffer.


        :param vendor: The vendor of this ListingOffer.  # noqa: E501
        :type: OfferVendor
        """

        self._vendor = vendor

    @property
    def category(self):
        """Gets the category of this ListingOffer.  # noqa: E501


        :return: The category of this ListingOffer.  # noqa: E501
        :rtype: OfferCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ListingOffer.


        :param category: The category of this ListingOffer.  # noqa: E501
        :type: OfferCategory
        """

        self._category = category

    @property
    def publication(self):
        """Gets the publication of this ListingOffer.  # noqa: E501


        :return: The publication of this ListingOffer.  # noqa: E501
        :rtype: OfferPublication
        """
        return self._publication

    @publication.setter
    def publication(self, publication):
        """Sets the publication of this ListingOffer.


        :param publication: The publication of this ListingOffer.  # noqa: E501
        :type: OfferPublication
        """

        self._publication = publication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListingOffer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListingOffer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OrderLineItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'offer': 'OfferReference',
        'quantity': 'float',
        'original_price': 'Price',
        'price': 'Price',
        'bought_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'offer': 'offer',
        'quantity': 'quantity',
        'original_price': 'originalPrice',
        'price': 'price',
        'bought_at': 'boughtAt'
    }

    def __init__(self, id=None, offer=None, quantity=None, original_price=None, price=None, bought_at=None, local_vars_configuration=None):  # noqa: E501
        """OrderLineItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._offer = None
        self._quantity = None
        self._original_price = None
        self._price = None
        self._bought_at = None
        self.discriminator = None

        self.id = id
        self.offer = offer
        self.quantity = quantity
        if original_price is not None:
            self.original_price = original_price
        self.price = price
        if bought_at is not None:
            self.bought_at = bought_at

    @property
    def id(self):
        """Gets the id of this OrderLineItem.  # noqa: E501

        Order item identifier  # noqa: E501

        :return: The id of this OrderLineItem.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrderLineItem.

        Order item identifier  # noqa: E501

        :param id: The id of this OrderLineItem.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def offer(self):
        """Gets the offer of this OrderLineItem.  # noqa: E501


        :return: The offer of this OrderLineItem.  # noqa: E501
        :rtype: OfferReference
        """
        return self._offer

    @offer.setter
    def offer(self, offer):
        """Sets the offer of this OrderLineItem.


        :param offer: The offer of this OrderLineItem.  # noqa: E501
        :type: OfferReference
        """
        if self.local_vars_configuration.client_side_validation and offer is None:  # noqa: E501
            raise ValueError("Invalid value for `offer`, must not be `None`")  # noqa: E501

        self._offer = offer

    @property
    def quantity(self):
        """Gets the quantity of this OrderLineItem.  # noqa: E501

        quantity  # noqa: E501

        :return: The quantity of this OrderLineItem.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this OrderLineItem.

        quantity  # noqa: E501

        :param quantity: The quantity of this OrderLineItem.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and quantity is None:  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501

        self._quantity = quantity

    @property
    def original_price(self):
        """Gets the original_price of this OrderLineItem.  # noqa: E501


        :return: The original_price of this OrderLineItem.  # noqa: E501
        :rtype: Price
        """
        return self._original_price

    @original_price.setter
    def original_price(self, original_price):
        """Sets the original_price of this OrderLineItem.


        :param original_price: The original_price of this OrderLineItem.  # noqa: E501
        :type: Price
        """

        self._original_price = original_price

    @property
    def price(self):
        """Gets the price of this OrderLineItem.  # noqa: E501


        :return: The price of this OrderLineItem.  # noqa: E501
        :rtype: Price
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this OrderLineItem.


        :param price: The price of this OrderLineItem.  # noqa: E501
        :type: Price
        """
        if self.local_vars_configuration.client_side_validation and price is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def bought_at(self):
        """Gets the bought_at of this OrderLineItem.  # noqa: E501

        ISO date when offer was bought  # noqa: E501

        :return: The bought_at of this OrderLineItem.  # noqa: E501
        :rtype: datetime
        """
        return self._bought_at

    @bought_at.setter
    def bought_at(self, bought_at):
        """Sets the bought_at of this OrderLineItem.

        ISO date when offer was bought  # noqa: E501

        :param bought_at: The bought_at of this OrderLineItem.  # noqa: E501
        :type: datetime
        """

        self._bought_at = bought_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderLineItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrderLineItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Pos(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'external_id': 'str',
        'name': 'str',
        'seller': 'Seller',
        'type': 'str',
        'address': 'Address',
        'phone_number': 'str',
        'email': 'str',
        'open_hours': 'list[OpenHour]',
        'service_time': 'str',
        'payments': 'list[Payment]',
        'confirmation_type': 'str',
        'status': 'str',
        'created_at': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'external_id': 'externalId',
        'name': 'name',
        'seller': 'seller',
        'type': 'type',
        'address': 'address',
        'phone_number': 'phoneNumber',
        'email': 'email',
        'open_hours': 'openHours',
        'service_time': 'serviceTime',
        'payments': 'payments',
        'confirmation_type': 'confirmationType',
        'status': 'status',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, external_id=None, name=None, seller=None, type=None, address=None, phone_number=None, email=None, open_hours=None, service_time=None, payments=None, confirmation_type=None, status=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """Pos - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._external_id = None
        self._name = None
        self._seller = None
        self._type = None
        self._address = None
        self._phone_number = None
        self._email = None
        self._open_hours = None
        self._service_time = None
        self._payments = None
        self._confirmation_type = None
        self._status = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if external_id is not None:
            self.external_id = external_id
        self.name = name
        if seller is not None:
            self.seller = seller
        self.type = type
        self.address = address
        if phone_number is not None:
            self.phone_number = phone_number
        if email is not None:
            self.email = email
        self.open_hours = open_hours
        if service_time is not None:
            self.service_time = service_time
        if payments is not None:
            self.payments = payments
        self.confirmation_type = confirmation_type
        self.status = status
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Pos.  # noqa: E501

        UUID. When creating a point of service (Post) the field is ignored. It is required when updating (Put) a point of service.  # noqa: E501

        :return: The id of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Pos.

        UUID. When creating a point of service (Post) the field is ignored. It is required when updating (Put) a point of service.  # noqa: E501

        :param id: The id of this Pos.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def external_id(self):
        """Gets the external_id of this Pos.  # noqa: E501

        ID from external client system.  # noqa: E501

        :return: The external_id of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Pos.

        ID from external client system.  # noqa: E501

        :param external_id: The external_id of this Pos.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                external_id is not None and len(external_id) > 80):
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `80`")  # noqa: E501

        self._external_id = external_id

    @property
    def name(self):
        """Gets the name of this Pos.  # noqa: E501


        :return: The name of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Pos.


        :param name: The name of this Pos.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 80):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `80`")  # noqa: E501

        self._name = name

    @property
    def seller(self):
        """Gets the seller of this Pos.  # noqa: E501


        :return: The seller of this Pos.  # noqa: E501
        :rtype: Seller
        """
        return self._seller

    @seller.setter
    def seller(self, seller):
        """Sets the seller of this Pos.


        :param seller: The seller of this Pos.  # noqa: E501
        :type: Seller
        """

        self._seller = seller

    @property
    def type(self):
        """Gets the type of this Pos.  # noqa: E501

        Indicates point type. The only valid value so far is PICKUP_POINT.  # noqa: E501

        :return: The type of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Pos.

        Indicates point type. The only valid value so far is PICKUP_POINT.  # noqa: E501

        :param type: The type of this Pos.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def address(self):
        """Gets the address of this Pos.  # noqa: E501


        :return: The address of this Pos.  # noqa: E501
        :rtype: Address
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Pos.


        :param address: The address of this Pos.  # noqa: E501
        :type: Address
        """
        if self.local_vars_configuration.client_side_validation and address is None:  # noqa: E501
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def phone_number(self):
        """Gets the phone_number of this Pos.  # noqa: E501


        :return: The phone_number of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this Pos.


        :param phone_number: The phone_number of this Pos.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                phone_number is not None and len(phone_number) > 16):
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `16`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def email(self):
        """Gets the email of this Pos.  # noqa: E501


        :return: The email of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Pos.


        :param email: The email of this Pos.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 64):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `64`")  # noqa: E501

        self._email = email

    @property
    def open_hours(self):
        """Gets the open_hours of this Pos.  # noqa: E501

        Possible empty list of opening hours.  # noqa: E501

        :return: The open_hours of this Pos.  # noqa: E501
        :rtype: list[OpenHour]
        """
        return self._open_hours

    @open_hours.setter
    def open_hours(self, open_hours):
        """Sets the open_hours of this Pos.

        Possible empty list of opening hours.  # noqa: E501

        :param open_hours: The open_hours of this Pos.  # noqa: E501
        :type: list[OpenHour]
        """
        if self.local_vars_configuration.client_side_validation and open_hours is None:  # noqa: E501
            raise ValueError("Invalid value for `open_hours`, must not be `None`")  # noqa: E501

        self._open_hours = open_hours

    @property
    def service_time(self):
        """Gets the service_time of this Pos.  # noqa: E501

        Delivery time / Time period for receipt. Date format ISO 8601 e.g. 'PT24H'  # noqa: E501

        :return: The service_time of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._service_time

    @service_time.setter
    def service_time(self, service_time):
        """Sets the service_time of this Pos.

        Delivery time / Time period for receipt. Date format ISO 8601 e.g. 'PT24H'  # noqa: E501

        :param service_time: The service_time of this Pos.  # noqa: E501
        :type: str
        """

        self._service_time = service_time

    @property
    def payments(self):
        """Gets the payments of this Pos.  # noqa: E501

        An empty list of payment types is available.  # noqa: E501

        :return: The payments of this Pos.  # noqa: E501
        :rtype: list[Payment]
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this Pos.

        An empty list of payment types is available.  # noqa: E501

        :param payments: The payments of this Pos.  # noqa: E501
        :type: list[Payment]
        """

        self._payments = payments

    @property
    def confirmation_type(self):
        """Gets the confirmation_type of this Pos.  # noqa: E501

        Confirmation method: AWAIT_CONTACT - We will inform you about the time of receipt, CALL_US - Please make an appointment, CONTACT_NOT_REQUIRED - Contact is not required.  # noqa: E501

        :return: The confirmation_type of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._confirmation_type

    @confirmation_type.setter
    def confirmation_type(self, confirmation_type):
        """Sets the confirmation_type of this Pos.

        Confirmation method: AWAIT_CONTACT - We will inform you about the time of receipt, CALL_US - Please make an appointment, CONTACT_NOT_REQUIRED - Contact is not required.  # noqa: E501

        :param confirmation_type: The confirmation_type of this Pos.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and confirmation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `confirmation_type`, must not be `None`")  # noqa: E501

        self._confirmation_type = confirmation_type

    @property
    def status(self):
        """Gets the status of this Pos.  # noqa: E501

        Point of service status: ACTIVE - active, TEMPORARILY_CLOSED - temporarily closed, CLOSED_DOWN - closed down, DELETED - deleted.  # noqa: E501

        :return: The status of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Pos.

        Point of service status: ACTIVE - active, TEMPORARILY_CLOSED - temporarily closed, CLOSED_DOWN - closed down, DELETED - deleted.  # noqa: E501

        :param status: The status of this Pos.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def created_at(self):
        """Gets the created_at of this Pos.  # noqa: E501

        Creation date. Date format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ When creating (Post) or updating (Put) a point of service (Post) the field is ignored.  # noqa: E501

        :return: The created_at of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Pos.

        Creation date. Date format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ When creating (Post) or updating (Put) a point of service (Post) the field is ignored.  # noqa: E501

        :param created_at: The created_at of this Pos.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Pos.  # noqa: E501

        Modification date. Date format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ When creating (Post) or updating (Put) a point of service (Post) the field is ignored.  # noqa: E501

        :return: The updated_at of this Pos.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Pos.

        Modification date. Date format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ When creating (Post) or updating (Put) a point of service (Post) the field is ignored.  # noqa: E501

        :param updated_at: The updated_at of this Pos.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pos):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Pos):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.order_event_data import OrderEventData  # noqa: E501
from allegro_api.rest import ApiException

class TestOrderEventData(unittest.TestCase):
    """OrderEventData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OrderEventData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.order_event_data.OrderEventData()  # noqa: E501
        if include_optional :
            return OrderEventData(
                seller = allegro_api.models.seller_reference.SellerReference(
                    id = '437848322', ), 
                buyer = allegro_api.models.buyer_reference.BuyerReference(
                    id = '23123123', 
                    email = 'user-email@allegro.pl', 
                    login = 'User_Login', 
                    guest = False, ), 
                line_items = [
                    allegro_api.models.order_line_item.OrderLineItem(
                        id = '62ae358b-8f65-4fc4-9c77-bedf604a2e2b', 
                        offer = allegro_api.models.offer_reference.OfferReference(
                            id = '3213213', 
                            name = 'Name of purchased offer', 
                            external = allegro_api.models.external_id.ExternalId(
                                id = 'AH-129834', ), ), 
                        quantity = 1, 
                        original_price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        bought_at = '2018-01-01T10:23:43.123Z', )
                    ], 
                checkout_form = allegro_api.models.checkout_form_reference.CheckoutFormReference(
                    id = '88ae369b-8f65-4fc4-9c77-bedf604a2e2b', )
            )
        else :
            return OrderEventData(
                seller = allegro_api.models.seller_reference.SellerReference(
                    id = '437848322', ),
                buyer = allegro_api.models.buyer_reference.BuyerReference(
                    id = '23123123', 
                    email = 'user-email@allegro.pl', 
                    login = 'User_Login', 
                    guest = False, ),
                line_items = [
                    allegro_api.models.order_line_item.OrderLineItem(
                        id = '62ae358b-8f65-4fc4-9c77-bedf604a2e2b', 
                        offer = allegro_api.models.offer_reference.OfferReference(
                            id = '3213213', 
                            name = 'Name of purchased offer', 
                            external = allegro_api.models.external_id.ExternalId(
                                id = 'AH-129834', ), ), 
                        quantity = 1, 
                        original_price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        bought_at = '2018-01-01T10:23:43.123Z', )
                    ],
        )

    def testOrderEventData(self):
        """Test OrderEventData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.points_of_service_api import PointsOfServiceApi  # noqa: E501
from allegro_api.rest import ApiException


class TestPointsOfServiceApi(unittest.TestCase):
    """PointsOfServiceApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.points_of_service_api.PointsOfServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_pos_using_post(self):
        """Test case for create_pos_using_post

        Create a point of service  # noqa: E501
        """
        pass

    def test_delete_pos_using_delete(self):
        """Test case for delete_pos_using_delete

        Delete a point of service  # noqa: E501
        """
        pass

    def test_get_pos_data_using_get(self):
        """Test case for get_pos_data_using_get

        Get the details of a point of service  # noqa: E501
        """
        pass

    def test_get_pos_list_using_get(self):
        """Test case for get_pos_list_using_get

        Get the user's points of service  # noqa: E501
        """
        pass

    def test_modify_pos_using_put(self):
        """Test case for modify_pos_using_put

        Modify a point of service  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_change_command import OfferChangeCommand  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferChangeCommand(unittest.TestCase):
    """OfferChangeCommand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferChangeCommand
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_change_command.OfferChangeCommand()  # noqa: E501
        if include_optional :
            return OfferChangeCommand(
                modification = allegro_api.models.modification.Modification(
                    additional_services_group = allegro_api.models.additional_services_group.AdditionalServicesGroup(
                        id = '0', ), 
                    delivery = allegro_api.models.modification_delivery.ModificationDelivery(
                        shipping_rates = allegro_api.models.shipping_rates.ShippingRates(
                            id = '0', ), ), 
                    payments = allegro_api.models.modification_payments.ModificationPayments(
                        invoice = 'VAT', ), 
                    promotion = allegro_api.models.modification_promotion.ModificationPromotion(
                        bold = False, 
                        department_page = False, 
                        emphasized = False, 
                        emphasized_highlight_bold_package = False, 
                        highlight = False, ), 
                    size_table = allegro_api.models.modification_size_table.ModificationSizeTable(
                        id = '0', ), 
                    publication = allegro_api.models.modification_publication.ModificationPublication(
                        duration = 'PT72H', 
                        duration_unlimited = False, ), ), 
                offer_criteria = [
                    allegro_api.models.offer_criterium.OfferCriterium(
                        offers = [
                            allegro_api.models.offer_id.OfferId(
                                id = '0', )
                            ], 
                        type = 'CONTAINS_OFFERS', )
                    ]
            )
        else :
            return OfferChangeCommand(
        )

    def testOfferChangeCommand(self):
        """Test OfferChangeCommand"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class SellerRebateDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'benefits': 'list[Benefit]',
        'created_at': 'datetime',
        'id': 'str',
        'offer_criteria': 'list[SellerRebateOfferCriterion]',
        'status': 'str'
    }

    attribute_map = {
        'benefits': 'benefits',
        'created_at': 'createdAt',
        'id': 'id',
        'offer_criteria': 'offerCriteria',
        'status': 'status'
    }

    def __init__(self, benefits=None, created_at=None, id=None, offer_criteria=None, status=None, local_vars_configuration=None):  # noqa: E501
        """SellerRebateDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._benefits = None
        self._created_at = None
        self._id = None
        self._offer_criteria = None
        self._status = None
        self.discriminator = None

        self.benefits = benefits
        if created_at is not None:
            self.created_at = created_at
        self.id = id
        self.offer_criteria = offer_criteria
        self.status = status

    @property
    def benefits(self):
        """Gets the benefits of this SellerRebateDto.  # noqa: E501

        What kind of rebate will be given  # noqa: E501

        :return: The benefits of this SellerRebateDto.  # noqa: E501
        :rtype: list[Benefit]
        """
        return self._benefits

    @benefits.setter
    def benefits(self, benefits):
        """Sets the benefits of this SellerRebateDto.

        What kind of rebate will be given  # noqa: E501

        :param benefits: The benefits of this SellerRebateDto.  # noqa: E501
        :type: list[Benefit]
        """
        if self.local_vars_configuration.client_side_validation and benefits is None:  # noqa: E501
            raise ValueError("Invalid value for `benefits`, must not be `None`")  # noqa: E501

        self._benefits = benefits

    @property
    def created_at(self):
        """Gets the created_at of this SellerRebateDto.  # noqa: E501

        when was this rebate created  # noqa: E501

        :return: The created_at of this SellerRebateDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SellerRebateDto.

        when was this rebate created  # noqa: E501

        :param created_at: The created_at of this SellerRebateDto.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this SellerRebateDto.  # noqa: E501

        Rebate identifier  # noqa: E501

        :return: The id of this SellerRebateDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SellerRebateDto.

        Rebate identifier  # noqa: E501

        :param id: The id of this SellerRebateDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def offer_criteria(self):
        """Gets the offer_criteria of this SellerRebateDto.  # noqa: E501

        What offers will be included  # noqa: E501

        :return: The offer_criteria of this SellerRebateDto.  # noqa: E501
        :rtype: list[SellerRebateOfferCriterion]
        """
        return self._offer_criteria

    @offer_criteria.setter
    def offer_criteria(self, offer_criteria):
        """Sets the offer_criteria of this SellerRebateDto.

        What offers will be included  # noqa: E501

        :param offer_criteria: The offer_criteria of this SellerRebateDto.  # noqa: E501
        :type: list[SellerRebateOfferCriterion]
        """
        if self.local_vars_configuration.client_side_validation and offer_criteria is None:  # noqa: E501
            raise ValueError("Invalid value for `offer_criteria`, must not be `None`")  # noqa: E501

        self._offer_criteria = offer_criteria

    @property
    def status(self):
        """Gets the status of this SellerRebateDto.  # noqa: E501


        :return: The status of this SellerRebateDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SellerRebateDto.


        :param status: The status of this SellerRebateDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["ACTIVE", "INACTIVE", "SUSPENDED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SellerRebateDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SellerRebateDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offers_search_result_dto import OffersSearchResultDto  # noqa: E501
from allegro_api.rest import ApiException

class TestOffersSearchResultDto(unittest.TestCase):
    """OffersSearchResultDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OffersSearchResultDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offers_search_result_dto.OffersSearchResultDto()  # noqa: E501
        if include_optional :
            return OffersSearchResultDto(
                offers = [
                    allegro_api.models.offer_listing_dto.OfferListingDto(
                        id = '2865624934', 
                        name = 'Buty damskie adidas', 
                        category = allegro_api.models.offer_category.OfferCategory(
                            id = '257929', ), 
                        primary_image = allegro_api.models.offer_listing_dto_image.OfferListingDtoImage(
                            url = 'https://a.allegroimg.com/original/05a2af/929c6dae4fb8721a8539582eb421', ), 
                        selling_mode = allegro_api.models.selling_mode.SellingMode(
                            format = 'BUY_NOW', 
                            price = null, 
                            minimal_price = null, 
                            starting_price = null, ), 
                        sale_info = allegro_api.models.offer_listing_dto_v1_sale_info.OfferListingDtoV1SaleInfo(
                            current_price = null, 
                            bidders_count = 4, ), 
                        stock = allegro_api.models.offer_listing_dto_v1_stock.OfferListingDtoV1Stock(
                            available = 23, 
                            sold = 3, ), 
                        stats = allegro_api.models.offer_listing_dto_v1_stats.OfferListingDtoV1Stats(
                            watchers_count = 99, 
                            visits_count = 56, ), 
                        publication = allegro_api.models.offer_listing_dto_v1_publication.OfferListingDtoV1Publication(
                            status = 'INACTIVE', 
                            starting_at = '2019-05-29T12:00:00Z', 
                            started_at = '2019-05-29T12:00:00Z', 
                            ending_at = '2019-06-30T12:00:00Z', 
                            ended_at = '2019-06-30T12:10:00Z', ), 
                        after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                            implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                            return_policy = allegro_api.models.return_policy.ReturnPolicy(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                            warranty = allegro_api.models.warranty.Warranty(
                                id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                        additional_services = allegro_api.models.offer_additional_services.OfferAdditionalServices(
                            id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                        external = allegro_api.models.external_id.ExternalId(
                            id = 'AH-129834', ), 
                        delivery = allegro_api.models.offer_listing_dto_v1_delivery.OfferListingDtoV1Delivery(
                            shipping_rates = allegro_api.models.shipping_rates.ShippingRates(
                                id = '0', ), ), )
                    ], 
                count = 1, 
                total_count = 1234
            )
        else :
            return OffersSearchResultDto(
        )

    def testOffersSearchResultDto(self):
        """Test OffersSearchResultDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.external_id import ExternalId  # noqa: E501
from allegro_api.rest import ApiException

class TestExternalId(unittest.TestCase):
    """ExternalId unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ExternalId
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.external_id.ExternalId()  # noqa: E501
        if include_optional :
            return ExternalId(
                id = 'AH-129834'
            )
        else :
            return ExternalId(
        )

    def testExternalId(self):
        """Test ExternalId"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
